@@ -25,21 +25,20 @@
    Ramey in GNU Bash, the Bourne Again SHell.  Copyright (C) 1987, 1988, 1989,
    1990, 1991, 1992 Free Software Foundation, Inc.  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include "gnome-vfs-private-utils.h"
 
 #include "gnome-vfs-cancellation.h"
-#include "gnome-vfs-constants.h"
 #include "gnome-vfs-ops.h"
-#include <ctype.h>
+#include "gnome-vfs-uri.h"
 #include <errno.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <time.h>
 #include <unistd.h>
 
 static int
@@ -392,11 +391,11 @@ check_end (const gchar *p)
 {
 	if (!p)
 		return 0;
-	while (isspace ((unsigned char)*p))
+	while (g_ascii_isspace (*p))
 		++p;
 	if (!*p
 	    || (p[0] == 'G' && p[1] == 'M' && p[2] == 'T')
-	    || ((p[0] == '+' || p[1] == '-') && isdigit ((unsigned char)p[1])))
+	    || ((p[0] == '+' || p[1] == '-') && g_ascii_isdigit (p[1])))
 		return 1;
 	else
 		return 0;
@@ -502,8 +501,8 @@ gnome_vfs_istr_has_prefix (const char *haystack, const char *needle)
 		}
 		hc = *h++;
 		nc = *n++;
-		hc = tolower ((guchar) hc);
-		nc = tolower ((guchar) nc);
+		hc = g_ascii_tolower (hc);
+		nc = g_ascii_tolower (nc);
 	} while (hc == nc);
 	return FALSE;
 }
@@ -536,8 +535,8 @@ gnome_vfs_istr_has_suffix (const char *haystack, const char *needle)
 		}
 		hc = *--h;
 		nc = *--n;
-		hc = tolower ((guchar) hc);
-		nc = tolower ((guchar) nc);
+		hc = g_ascii_tolower (hc);
+		nc = g_ascii_tolower (nc);
 	} while (hc == nc);
 	return FALSE;
 }
